@@ -1,4 +1,4 @@
-__version__ = '0.2.5'
+__version__ = '0.2.6'
 
 PID_FILE = '/tmp/yedb-server.pid'
 
@@ -70,7 +70,8 @@ METHODS = [
     'key_get_recursive', 'key_copy', 'key_rename', 'key_exists', 'key_explain',
     'key_delete', 'key_delete_recursive', 'purge', 'check', 'repair', 'info',
     'key_dump', 'key_load', 'key_update', 'safe_purge', 'purge_cache',
-    'server_set', 'key_increment', 'key_decrement'
+    'server_set', 'key_increment', 'key_decrement', 'key_get_field',
+    'key_set_field'
 ]
 
 
